void foo();

void sparta()
{
}

void slavia();

int bar()
{
  sparta ();
  return 2;
}

const char *baz()
{
  return "baz";
}
